misc/isolate_runner library
Classes
-
IsolateRunner<
T> - An IsolateRunner is a runner for executing a computation in a separate Isolate, with the possibility of externally controlled cancellation with immediate termination, with termination when control is yielded back to the event loop, or with termination using cancellation token.