isPaused property
bool
get
isPaused
Returns true if the token is in a paused state.
Implementation
bool get isPaused => _isPaused;
Returns true if the token is in a paused state.
bool get isPaused => _isPaused;