pause method
Signal to associated token that the operation executions should be paused.
Implementation
Future<void> pause() {
return token._pause();
}
Signal to associated token that the operation executions should be paused.
Future<void> pause() {
return token._pause();
}