resume method
Signal to associated token that the operation executions should be resumed.
Implementation
Future<void> resume() {
return token._resume();
}
Signal to associated token that the operation executions should be resumed.
Future<void> resume() {
return token._resume();
}