Progress<T> class

The Progress class is intended for monitoring the execution of operations where progress can be measured quantitatively.

Constructors

Progress(FutureOr<void> callback(T value))
Creates an instance of Progress.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report(T value) → void
Notifies the the reporting function.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited