add method
Adds the specified amount of data for the measuring.
Implementation
void add(int amount) {
if (!_clock.isRunning) {
return;
}
_currentAmount = _currentAmount + amount;
_totalAmount = _totalAmount + amount;
}
Adds the specified amount of data for the measuring.
void add(int amount) {
if (!_clock.isRunning) {
return;
}
_currentAmount = _currentAmount + amount;
_totalAmount = _totalAmount + amount;
}