Throughput<T extends num> class

A Throughput allows to measure data transfer speed.\

Constructors

Throughput()

Properties

elapsedNanoseconds int
Returns the elapsed time in nanoseconds.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
units → T
no setter

Methods

add(T units) → void
Adds the specified number of units to the total number of units.
measure() double
Measures the average speed at the moment and returns the speed of processing units per second.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited