multitasking library
Classes
- CancelableStreamFactory
-
A CancelableStreamFactory is a Stream factory which delegates stream
creation to a function with a
tokenparameter, which takes responsibility for creating a stream that will support cancellation of a subscription when cancellation is requested via a CancellationToken. - CancellationToken
- A CancellationToken is a mechanism for cooperative cancellation of asynchronous operations.
- CancellationTokenSource
-
A CancellationTokenSource class manages the cancellation process for
asynchronous operations.
It works in conjunction with the CancellationToken class, providing acooperativecancellation mechanism. -
CancellationTransformer<
T> -
A CancellationTransformer is a transformer which allows to
cancela subscription using acancellation tokenor a specifiedtimeout, with support fornon-blockingcancellation, and with support for sending a request topausea stream andresumeafter a pause using apause token. -
PauseTransformer<
T> - A PauseTransformer is a transformer which allows to pause/resume a stream subscription using a PauseToken.
-
Task<
T> -
A Task is an object representing some operation that will complete in the future.
Tasks are executed asynchronously and cooperatively.
Cooperative multitasking is a concurrency model where tasks voluntarily yield control (usingawait). -
TaskCompletionSource<
T> - A TaskCompletionSource is a producer of the tasks that can complete with a value, with an error, or in a canceled state.
Enums
- TaskStatus
- Represents the status of a task.
Extensions
-
StreamExtension
on Stream<
T> - A StreamExtension is an extension for Stream with various useful methods.
Exceptions / Errors
- AggregateError
- Represents an error that aggregates other errors amd exceptions and their stack traces.
- CancellationException
- Represents an exception used to indicate that the operation was canceled.
- TaskStateError
- Represents an error that occurs when an operation is requested on a Task whose current state does not allow the operation to be performed.