AggregateError class

Represents an error that aggregates other errors amd exceptions and their stack traces.

Inheritance

Constructors

AggregateError(List<AsyncError> exceptions)
Creates an instance of AggregateError.

Properties

exceptions List<AsyncError>
Returns a list of inner exceptions.
no setter
hashCode int
The hash code for this object.
no setterinherited
message String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
The stack trace associated with this error.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited