CancellationException class

Represents an exception used to indicate that the operation was canceled.

Implemented types

Constructors

CancellationException([String? message])
Creates an instance of CancellationException.

Properties

hashCode int
The hash code for this object.
no setterinherited
message String?
Message associated with this exception.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited