reacquire method

  1. @override
Future<void> reacquire()
override

Reacquires the lock as quickly as possible.
This method is not recommended for direct use.
This method is intended exclusively to ensure fair operation of reacquiring the lock in condition variable in the wait() method.

Typically, when this method is called, the waiter is placed in a queue with a priority higher than the entrance queue to avoid starvation.

Implementation

@override
Future<void> reacquire() async {
  return _acquire(_waitQueue);
}