ManualResetEvent class

A ManualResetEvent is a synchronization primitive that is used to manage signaling.
When an event is in a signaled state, any calls to the wait method will not block execution of the calling code.
When an event is in a non-signaled state, any calls to the wait method will block execution of the calling code.

Once switched to the signaled state, the event remains in the signaled state until it is manually reset.

Constructors

ManualResetEvent(bool isSet)

Properties

hashCode int
The hash code for this object.
no setterinherited
isSet bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() Future<void>
Switches the event back to the non-signaled state.
All subsequent calls to the wait method will block the calling code.
inherited
set() Future<void>
Switches the event into the signaled state.
Any subsequent calls to the wait method will not block execution of the calling code.
toString() String
A string representation of this object.
inherited
tryWait(Duration timeout) Future<bool>
wait() Future<void>
The calling code calls this method to wait for the signal.
If the event is in the non-signaled state, the calling code blocks.
If the event is in the signaled state, the calling code continues execution.

Operators

operator ==(Object other) bool
The equality operator.
inherited