run abstract method
Executes the computation and returns the computation result (or throws the exception), or throws the CancellationException exception.
Implementation
Future<T> run();
Executes the computation and returns the computation result (or throws the exception), or throws the CancellationException exception.
Future<T> run();