CountdownTimer class

A CountdownTimer is a Timer that has the following features:

Implemented types

Constructors

CountdownTimer(Duration duration, void callback())

Properties

duration Duration
Returns the timer duration
getter/setter pair
elapsedMicroseconds int
Returns the elapsed time in microseconds.
no setter
hashCode int
The hash code for this object.
no setterinherited
isActive bool
Returns whether the timer is still active.
no setteroverride
remainingMicroseconds int
Returns the remaining time in microseconds.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tick int
The number of durations preceding the most recent timer event.
no setteroverride

Methods

cancel() → void
Cancels the timer.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Resets the time countdown.
start() → void
Starts (or resumes) the time countdown.
stop() → void
Stops (or pauses) the time countdown.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited