PauseToken class
A PauseToken is a mechanism for cooperative pause/resume of asynchronous
operations.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runPausable<
T> (FutureOr< void> onPause(), FutureOr<void> onResume(), FutureOr<T> action()) → Future<T> - Performs the following actions:
-
toString(
) → String -
A string representation of this object.
inherited
-
wait(
{CancellationToken? token}) → Future< void> -
If the token is in the
pausedstate, then it pauses execution of the calling code until it receives theresumesignal.
If the token is not in thepausedstate, then execution of the calling code continues immediately.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited