PauseTokenSource class

A PauseTokenSource class manages the the pause/resume process for asynchronous operations.
It works in conjunction with the PauseToken class, providing a cooperative pause/resume mechanism.

Constructors

PauseTokenSource()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token PauseToken
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
Signal to associated token that the operation executions should be paused.
resume() → void
Signal to associated token that the operation executions should be resumed.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited