pause method
void
pause()
Signal to associated token that the operation executions should be paused.
Implementation
void pause() {
token._pause();
}
Signal to associated token that the operation executions should be paused.
void pause() {
token._pause();
}