resume method
void
resume()
Signal to associated token that the operation executions should be resumed.
Implementation
void resume() {
token._resume();
}
Signal to associated token that the operation executions should be resumed.
void resume() {
token._resume();
}