SpeedMeter class
The SpeedMeter class is intended to measure the date processing or transferring speed.
Constructors
- SpeedMeter()
-
Creates an instance of SpeedMeter in the
pausedstate. - SpeedMeter.run()
- Creates an instance of SpeedMeter and starts the measurement.
Properties
- elapsedMicroseconds → int
-
Returns the cumulative time of measurements.\
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
no setter
- totalAmount → int
-
Returns the total amount of data added.
no setter
Methods
-
add(
int amount) → void -
Adds the specified
amountof data for the measuring. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void - Pauses the measurement.
-
reset(
) → void - Resets the measurement values.
-
resume(
) → void - Resumes the measurement.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited