TokenBucket class
- Annotations
-
- @Deprecated('Will be removed in the next version')
Constructors
- TokenBucket({required double capacity, required double rate})
- Creates an instance of TokenBucket.\
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
allowRequest(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited