CancellationToken class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
Returns the state of the token.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addHandler(
void handler()) → void Function()? -
Adds and returns a handler if the token is not in the
canceledstate. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removerHandler(
void handler()?) → void -
throwIfCancelled(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited