synchronization/condition_variable library
Classes
- ConditionVariable
-
A ConditionVariable is a synchronization primitive that allows to wait
for a particular condition to become
truebefore proceeding.
It is always used in conjunction with a locking to safely manage access to the shared data and prevent race conditions.