Lock class abstract

Implementers

Constructors

Lock()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquire() Future<void>
lock(FutureOr<void> action()) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reacquire() Future<void>
Reacquires the lock as quickly as possible.
This method is not recommended for direct use.
This method is intended exclusively to ensure fair operation of reacquiring the lock in condition variable in the wait() method.
release() Future<void>
toString() String
A string representation of this object.
inherited
tryAcquire(Duration timeout) Future<bool>
tryLock(Duration timeout, FutureOr<void> action()) Future<bool>

Operators

operator ==(Object other) bool
The equality operator.
inherited