MultipleWriteSingleReadObject<T> class
A MultipleWriteSingleReadObject is a synchronized object.
If an object is not held by one or more writers, then readers can access
the value of and object (using the read method) without any delay, having
previously checked the state of the object by reading the value isLocked.
If a object is held by one or more writers, then readers must waiting
for the write operations to complete using the wait method.
After that, a value cad be accessed immediately using the read method.
If an object is held by one or more readers and a write operation is
requested, the writer will wait for all previous read and write
operations.
Constructors
- MultipleWriteSingleReadObject(T value)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
) → T -
toString(
) → String -
A string representation of this object.
inherited
-
wait(
) → Future< void> -
write(
FutureOr< T> action(T value)) → Future<void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited