ReentrantLock class

A ReentrantLock is a synchronization primitive that works like a mutex.
It blocks execution of all zones that do not own this lock.
The zone that acquired the permit becomes the owner of this lock.
The zone owner can enter and exit as long as it holds this lock.

Inheritance

Constructors

ReentrantLock()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquire() Future<void>
override
lock(FutureOr<void> action()) Future<void>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() Future<void>
override
toString() String
A string representation of this object.
inherited
tryAcquire(Duration timeout) Future<bool>
override
tryLock(Duration timeout, FutureOr<void> action()) Future<bool>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited