synchronization/reset_events library

Classes

AutoResetEvent
A AutoResetEvent is a synchronization primitive that is used to manage signaling.
When an event is in a signaled state, any calls to the wait method will not block execution of the calling code.
When an event is in a non-signaled state, any calls to the wait method will block execution of the calling code.
ManualResetEvent
A ManualResetEvent is a synchronization primitive that is used to manage signaling.
When an event is in a signaled state, any calls to the wait method will not block execution of the calling code.
When an event is in a non-signaled state, any calls to the wait method will block execution of the calling code.