set method
Switches an event in the signaled state, allowing a single waiting code
to continue executing.
If there is no waiting code, the event remains in signaled state until
the wait method is called.
Implementation
Future<void> set() {
_isSet = true;
if (_queue.isNotEmpty) {
_isSet = false;
_queue.dequeue();
}
return _ResetEvent._void;
}