ManualResetEvent class

Constructors

ManualResetEvent(bool isSet)

Properties

hashCode int
The hash code for this object.
no setterinherited
isSet bool
no setterinherited
mode EventResetMode
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() Future<void>
inherited
set() Future<void>
inherited
toString() String
A string representation of this object.
inherited
tryWait(Duration timeout) Future<bool>
inherited
wait() Future<void>
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited